@@ -1,5 +1,17 @@
 from __future__ import annotations
-from typing import Any, Dict, List, NoReturn, Sequence, Tuple, Type, Union, Optional
+from typing import (
+    Any,
+    Dict,
+    Iterable,
+    List,
+    NoReturn,
+    Sequence,
+    Tuple,
+    Type,
+    TypeVar,
+    Union,
+    Optional,
+)
 
 from graia.application.exceptions import EntangledSuperposition
 from graia.broadcast.utilles import run_always_await
@@ -9,15 +21,10 @@ from .elements import ExternalElement, InternalElement, Element
 import regex
 import copy
 
-
-T = Element
+T = TypeVar("T", bound=Type[Element])
 MessageIndex = Tuple[int, Optional[int]]
 
 
-def raiser(error):
-    raise error
-
-
 class MessageChain(BaseModel):
     """即 "消息链", 被用于承载整个消息内容的数据结构, 包含有一有序列表, 包含有继承了 Element 的各式类实例.
 
@@ -217,7 +224,7 @@ class MessageChain(BaseModel):
                     await run_always_await(
                         i.toExternal(
                             *(extra[i.__class__][0] if i.__class__ in extra else []),
-                            **(extra[i.__class__][1] if i.__class__ in extra else {})
+                            **(extra[i.__class__][1] if i.__class__ in extra else {}),
                         )
                     )
                 )
@@ -236,7 +243,7 @@ class MessageChain(BaseModel):
         """
         return element_class in [type(i) for i in self.__root__]
 
-    def get(self, element_class: Type[Element]) -> List[T]:
+    def get(self, element_class: T) -> List[T]:
         """获取消息链中所有特定类型的消息元素
 
         Args:
@@ -247,6 +254,29 @@ class MessageChain(BaseModel):
         """
         return [i for i in self.__root__ if type(i) is element_class]
 
+    def getOne(self, element_class: T, index: int) -> T:
+        """获取消息链中第 index + 1 个特定类型的消息元素
+
+        Args:
+            element_class (Type[Element]): 指定的消息元素的类型, 例如 "Plain", "At", "Image" 等.
+            index (int): 索引, 从 0 开始数
+
+        Returns:
+            T: 消息链第 index + 1 个特定类型的消息元素
+        """
+        return self.get(element_class)[index]
+
+    def getFirst(self, element_class: T) -> T:
+        """获取消息链中第 1 个特定类型的消息元素
+
+        Args:
+            element_class (Type[Element]): 指定的消息元素的类型, 例如 "Plain", "At", "Image" 等.
+
+        Returns:
+            T: 消息链第 1 个特定类型的消息元素
+        """
+        return self.getOne(element_class, 0)
+
     def asDisplay(self) -> str:
         """获取以字符串形式表示的消息链, 且趋于通常你见到的样子.
 
@@ -298,7 +328,7 @@ class MessageChain(BaseModel):
                 "{0} is not allowed for item getting".format(type(item))
             )
 
-    def subchain(self, item: slice) -> "MessageChain":
+    def subchain(self, item: slice, ignore_text_index: bool = False) -> "MessageChain":
         """对消息链执行分片操作
 
         Args:
@@ -317,16 +347,20 @@ class MessageChain(BaseModel):
             first_slice = result[item.start[0] :]
             if item.start[1] is not None and first_slice:  # text slice
                 if not isinstance(first_slice[0], Plain):
-                    raise TypeError(
-                        "the sliced chain does not starts with a Plain: {}".format(
-                            first_slice[0]
+                    if not ignore_text_index:
+                        raise TypeError(
+                            "the sliced chain does not starts with a Plain: {}".format(
+                                first_slice[0]
+                            )
                         )
-                    )
-                final_text = first_slice[0].text[item.start[1] :]
-                result = [
-                    *([Plain(final_text)] if final_text else []),
-                    *first_slice[1:],
-                ]
+                    else:
+                        result = first_slice
+                else:
+                    final_text = first_slice[0].text[item.start[1] :]
+                    result = [
+                        *([Plain(final_text)] if final_text else []),
+                        *first_slice[1:],
+                    ]
             else:
                 result = first_slice
         if item.stop:
@@ -492,3 +526,40 @@ class MessageChain(BaseModel):
             MessageChain: 不包含以上元素的消息链.
         """
         return self.exclude(Source, Quote, Xml, Json, App, Poke)
+
+    def __repr__(self) -> str:
+        return f"MessageChain({repr(self.__root__)})"
+
+    def __iter__(self) -> Iterable[Element]:
+        yield from self.__root__
+
+    def startswith(self, string: str) -> bool:
+        from .elements.internal import Plain
+
+        if not self.__root__ or type(self.__root__[0]) is not Plain:
+            return False
+        return self.__root__[0].text.startswith(string)
+
+    def endswith(self, string: str) -> bool:
+        from .elements.internal import Plain
+
+        if not self.__root__ or type(self.__root__[-1]) is not Plain:
+            return False
+        return self.__root__[-1].text.endswith(string)
+
+    def hasText(self, string: str) -> bool:
+        """判定消息链内是否包括相应字符串
+
+        Args:
+            string (str): 需要判断的字符串
+
+        Returns:
+            bool: 是否包括
+        """
+
+        from .elements.internal import Plain
+
+        for i in self.get(Plain):
+            if string in i.text:
+                return True
+        return False
